"use strict";
/*
 * Copyright (C) 2017, 2018 TypeFox and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
const protocol_translation_1 = require("./protocol-translation");
const debounce = require("p-debounce");
class DiagnosticEventQueue {
    constructor(publicDiagnostics, logger) {
        this.publicDiagnostics = publicDiagnostics;
        this.logger = logger;
        this.diagnostics = new Map();
        this.firePublishDiagnostics = debounce((file) => {
            const uri = protocol_translation_1.pathToUri(file);
            const diagnostics = this.getDiagnostics(file);
            this.publicDiagnostics({ uri, diagnostics });
        }, 50);
    }
    updateDiagnostics(kind, event) {
        if (!event.body) {
            this.logger.error(`Received empty ${event.event} diagnostics.`);
            return;
        }
        const { file } = event.body;
        const diagnostics = this.diagnostics.get(file) || new Map();
        diagnostics.set(kind, event.body.diagnostics.map(protocol_translation_1.toDiagnostic));
        this.diagnostics.set(file, diagnostics);
        this.firePublishDiagnostics(file);
    }
    getDiagnostics(file) {
        const diagnostics = this.diagnostics.get(file);
        if (!diagnostics) {
            return [];
        }
        const result = [];
        for (const value of diagnostics.values()) {
            result.push(...value);
        }
        return result;
    }
}
exports.DiagnosticEventQueue = DiagnosticEventQueue;
//# sourceMappingURL=diagnostic-queue.js.map